=======
History
=======

0.1.4 (2021-09-09)
------------------

* improved test coverage
* improve TimeSeries equality check
* support NaN-removal in as_pd_series-method


0.1.3 (2021-09-08)
------------------

* remove manual timezone checks because it is handled by pandas
* fix skipped tests
* fix repr() method of TimestampSeries
* fix basic calculation with units involved


0.1.2 (2021-09-07)
------------------

* fix timezone handling
* First release on PyPI Index.



0.1.1 (2021-02-16)
------------------

* First release on PyPI Test Index.
